# Abaqus Session

Session commands are used to create objects that are not stored with the model; for example, viewports and display groups. Abaqus/CAE retains Session objects only for the duration of the session; they are not saved when the model database is saved.

```{toctree}
:caption: Objects of Session
:maxdepth: 1

session/animation
session/canvas
session/display_options
session/display
session/field_report
session/odb_display
session/path
session/plot_options
session/print
session/xy
```

## Classes

### Session

```{eval-rst}
.. autoclass:: abaqus.Session.Session.Session
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### SessionBase

```{eval-rst}
.. autoclass:: abaqus.Session.SessionBase.SessionBase
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### AnimationSession

```{eval-rst}
.. autoclass:: abaqus.Animation.AnimationSession.AnimationSession
    :members:
    :special-members: __init__
    :show-inheritance:
    :noindex:

    .. autoclasstoc::
```

### CanvasSession

```{eval-rst}
.. autoclass:: abaqus.Canvas.CanvasSession.CanvasSession
    :members:
    :special-members: __init__
    :show-inheritance:
    :noindex:

    .. autoclasstoc::
```

### DisplayGroupSession

```{eval-rst}
.. autoclass:: abaqus.DisplayGroup.DisplayGroupSession.DisplayGroupSession
    :members:
    :special-members: __init__
    :show-inheritance:
    :noindex:

    .. autoclasstoc::
```

### FieldReportSession

```{eval-rst}
.. autoclass:: abaqus.FieldReport.FieldReportSession.FieldReportSession
    :members:
    :special-members: __init__
    :show-inheritance:
    :noindex:

    .. autoclasstoc::
```

### JobSession

```{eval-rst}
.. autoclass:: abaqus.Job.JobSession.JobSession
    :members:
    :special-members: __init__
    :show-inheritance:
    :noindex:

    .. autoclasstoc::
```

### OdbSession

```{eval-rst}
.. autoclass:: abaqus.Odb.OdbSession.OdbSession
    :members:
    :special-members: __init__
    :show-inheritance:
    :noindex:

    .. autoclasstoc::
```

### PathSession

```{eval-rst}
.. autoclass:: abaqus.PathAndProbe.PathSession.PathSession
    :members:
    :special-members: __init__
    :show-inheritance:
    :noindex:

    .. autoclasstoc::
```

### XYSession

```{eval-rst}
.. autoclass:: abaqus.XY.XYSession.XYSession
    :members:
    :special-members: __init__
    :show-inheritance:
    :noindex:

    .. autoclasstoc::

```

### AutoColors

```{eval-rst}
.. autoclass:: abaqus.Session.AutoColors.AutoColors
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### Color

```{eval-rst}
.. autoclass:: abaqus.Session.Color.Color
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### Drawing

```{eval-rst}
.. autoclass:: abaqus.Session.Drawing.Drawing
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### Image

```{eval-rst}
.. autoclass:: abaqus.Session.Image.Image
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### JournalOptions

```{eval-rst}
.. autoclass:: abaqus.Session.JournalOptions.JournalOptions
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### MemoryReductionOptions

```{eval-rst}
.. autoclass:: abaqus.Session.MemoryReductionOptions.MemoryReductionOptions
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### NetworkDatabaseConnector

```{eval-rst}
.. autoclass:: abaqus.Session.NetworkDatabaseConnector.NetworkDatabaseConnector
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### NumberFormat

```{eval-rst}
.. autoclass:: abaqus.Session.NumberFormat.NumberFormat
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```
